@@ -13,9 +13,8 @@ def communicationInitialization(port, baudrate):
 
 
 def executeCommand(pump, command, waitForPump=False):
-    result = commands.forwardType(pump.type)
-    if result:
-        communication.send_command(pump.asciiAddress, command, waitForPump)
+    commands.forwardType(pump.type)
+    communication.send_command(pump.asciiAddress, command, waitForPump)
 
 
 def definePump(address: str, type=4, baudRate=9600, resolutionMode=0):
