@@ -37,9 +37,12 @@ class PositionInShortestDirection(Enum):
 
 
 class PSDTypes(Enum):
-    PSD4 = '4'
-    PSD6 = '6'
-    PSD4_SMOOTH_FLOW = '4sf'
-    PSD6_SMOOTH_FLOW = '6sf'
+    psd4 = '4'
+    psd6 = '6'
+    psd4SmoothFlow = '4sf'
+    psd6SmoothFlow = '6sf'
+
+
+
 
 
